Package: vasicekfit
Title: Extended Vasicek Credit Loss Model with Macroeconomic Factors
Version: 0.1.0
Authors@R: person("Dmitriy", "Mayorov", email = "cran@dimview.org",
                  role = c("aut", "cre"))
Description: Fits the extended Vasicek single-factor credit loss model where
    the probability of default depends on macroeconomic covariates. Maximum
    likelihood estimates of all parameters, including asset value correlation,
    are obtained via closed-form probit-transformed OLS regression; see
    Mayorov (2026) <doi:10.2139/ssrn.6506378> for derivation.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 3.5.0)
Imports: stats
Suggests: testthat (>= 3.0.0), vasicek
Config/testthat/edition: 3
URL: https://github.com/externalmemory/vasicekfit-cran-package
BugReports: https://github.com/externalmemory/vasicekfit-cran-package/issues
NeedsCompilation: no
Packaged: 2026-04-23 22:22:06 UTC; default
Author: Dmitriy Mayorov [aut, cre]
Maintainer: Dmitriy Mayorov <cran@dimview.org>
Repository: CRAN
Date/Publication: 2026-04-28 18:50:02 UTC
Built: R 4.5.2; ; 2026-04-28 20:08:54 UTC; unix
